# Changelog

All notable changes to this project will be documented in this file.

The format is based on Keep a Changelog, and this project adheres to Semantic Versioning.

## [0.1.6] - 2024-04-15

### Fixed

- print of figure in console in `plugin.py`

## [0.1.5] - 2024-04-15

### Added

- support for relative link to figures when tof file is contain in a subdirectory in `plugin.py`
- markdown="span" to support new md-in-html requirements based on mkdocs-material documentation in `plugin.py`

## [0.1.4] - 2023-06-09

### Added

- md_in_html support for relative link to image in `plugin.py`

## [0.1.3] - 2023-06-09

### Fixed

- integration of unwanted mermaid diagrams when title is empty in `plugin.py`

## [0.1.2] - 2023-06-09

### Fixed

- relative path to local image transformed to absolute path using site_url in `plugin.py`

## [0.1.1] - 2023-06-09

### Removed

- debug print of each figure in `plugin.py`

## [0.1.0] - 2023-06-09

### Added

- `readme.md`
- `plugin.py`
- Support for `Mermaid` diagrams

[0.1.4]: https://gitlab.com/cfpt-mkdocs-plugins/mkdocs-table-of-figures/-/releases/v0.1.4